@@ -14,12 +14,12 @@ game server) sometimes need to load large Storable objects without
 blocking the server for a long time.
 
 This is being implemented by using a perlio layer that feeds only small
-amounts of data (512 bytes per call) into Storable, and C<Coro::cede>'ing
+amounts of data (4096 bytes per call) into Storable, and C<Coro::cede>'ing
 regularly (at most 100 times per second by default, though).
 
-As it seems that Storable is not reentrant, this module also wraps most
-functions of the Storable module so that only one freeze or thaw is done
-at any one moment (recursive invocations are not currently supported).
+As Storable is not reentrant, this module also wraps most functions of the
+Storable module so that only one freeze or thaw is done at any one moment
+(and recursive invocations are not currently supported).
 
 =head1 FUNCTIONS
 
@@ -31,16 +31,14 @@ Retrieve an object from the given $pst, which must have been created with
 C<Coro::Storable::freeze> or C<Storable::store_fd>/C<Storable::store>
 (sorry, but Storable uses incompatible formats for disk/mem objects).
 
-This works by calling C<Coro::cede> for every 4096 bytes read in.
+This function will cede regularly.
 
 =item $pst = freeze $ref
 
 Freeze the given scalar into a Storable object. It uses the same format as
 C<Storable::store_fd>.
 
-This works by calling C<Coro::cede> for every write that Storable
-issues. Unfortunately, Storable often makes many very small writes, so it
-is rather inefficient. But it does keep the latency low.
+This functino will cede regularly.
 
 =item $pst = nfreeze $ref
 
@@ -53,7 +51,7 @@ Same as C<freeze> but is guaranteed to block. This is useful e.g. in
 C<Coro::Util::fork_eval> when you want to serialise a data structure
 for use with the C<thaw> function for this module. You cannot use
 C<Storable::freeze> for this as Storable uses incompatible formats for
-memory and file images.
+memory and file images, and this module uses file images.
 
 =item $pst = blocking_nfreeze $ref
 
@@ -63,7 +61,7 @@ Same as C<blocking_freeze> but uses C<nfreeze> internally.
 
 Acquire the Storable lock, for when you want to call Storable yourself.
 
-Note that this module already wraps the Storable functions, so there is
+Note that this module already wraps all Storable functions, so there is
 rarely the need to do this yourself.
 
 =back
@@ -87,9 +85,11 @@ BEGIN {
 use Storable;
 use base "Exporter";
 
-our $VERSION = 4.746;
+our $VERSION = 4.749;
 our @EXPORT = qw(thaw freeze nfreeze blocking_thaw blocking_freeze blocking_nfreeze);
 
+our $GRANULARITY = 0.01;
+
 my $lock = new Coro::Semaphore;
 
 sub guard {
@@ -97,7 +97,7 @@ sub guard {
 }
 
 # wrap xs functions
-for (qw(net_pstore mstore net_mstore pretrieve mretrieve dclone)) {
+for (qw(net_pstore pstore net_mstore mstore pretrieve mretrieve dclone)) {
    my $orig = \&{"Storable::$_"};
    *{"Storable::$_"} = sub {
       my $guard = $lock->guard;
@@ -107,22 +107,26 @@ for (qw(net_pstore mstore net_mstore pretrieve mretrieve dclone)) {
 }
 
 sub thaw($) {
-   open my $fh, "<:via(CoroCede)", \$_[0]
-      or die "cannot open pst via CoroCede: $!";
+   open my $fh, "<:cede($GRANULARITY)", \$_[0]
+      or die "cannot open pst via PerlIO::cede: $!";
    Storable::fd_retrieve $fh
 }
 
 sub freeze($) {
-   open my $fh, ">:via(CoroCede)", \my $buf
-      or die "cannot open pst via CoroCede: $!";
+   open my $fh, ">:cede($GRANULARITY)", \my $buf
+      or die "cannot open pst via PerlIO::cede: $!";
    Storable::store_fd $_[0], $fh;
+   close $fh;
+
    $buf
 }
 
 sub nfreeze($) {
-   open my $fh, ">:via(CoroCede)", \my $buf
-      or die "cannot open pst via CoroCede: $!";
+   open my $fh, ">:cede($GRANULARITY)", \my $buf
+      or die "cannot open pst via PerlIO::cede: $!";
    Storable::nstore_fd $_[0], $fh;
+   close $fh;
+
    $buf
 }
 
@@ -150,41 +154,6 @@ sub blocking_nfreeze($) {
    $buf
 }
 
-package PerlIO::via::CoroCede;
-
-# generic cede-on-read/write filtering layer
-
-use Time::HiRes ("time");
-
-our $GRANULARITY = 0.01;
-
-my $next_cede;
-
-sub PUSHED {
-   __PACKAGE__
-}
-
-sub FILL {
-   if ($next_cede <= time) {
-      $next_cede = time + $GRANULARITY; # calling time() twice usually is a net win
-      Coro::cede ();
-   }
-
-   read $_[1], my $buf, 512
-      or return undef;
-
-   $buf
-}
-
-sub WRITE {
-   if ($next_cede <= time) {
-      $next_cede = time + $GRANULARITY;
-      Coro::cede ();
-   }
-
-   (print {$_[2]} $_[1]) ? length $_[1] : -1
-}
-
 1;
 
 =head1 AUTHOR
